@@ -9,12 +9,7 @@
 
 #include <QObject>
 
-#include <kauth_version.h>
-#if KAUTH_VERSION >= QT_VERSION_CHECK(5, 92, 0)
 #include <KAuth/ActionReply>
-#else
-#include <KAuth>
-#endif
 
 using namespace KAuth;
 
